@@ -1,5 +1,5 @@
 import test from 'ava';
-import normalizeUrl from '.';
+import normalizeUrl from './index.js';
 
 test('main', t => {
 	t.is(normalizeUrl('sindresorhus.com'), 'http://sindresorhus.com');
@@ -34,6 +34,7 @@ test('main', t => {
 	t.is(normalizeUrl('//sindresorhus.com:80/', {normalizeProtocol: false}), '//sindresorhus.com');
 	t.is(normalizeUrl('http://sindresorhus.com/foo#bar'), 'http://sindresorhus.com/foo#bar');
 	t.is(normalizeUrl('http://sindresorhus.com/foo#bar', {stripHash: true}), 'http://sindresorhus.com/foo');
+	t.is(normalizeUrl('http://sindresorhus.com/foo#bar:~:text=hello%20world', {stripHash: true}), 'http://sindresorhus.com/foo');
 	t.is(normalizeUrl('http://sindresorhus.com/foo/bar/../baz'), 'http://sindresorhus.com/foo/baz');
 	t.is(normalizeUrl('http://sindresorhus.com/foo/bar/./baz'), 'http://sindresorhus.com/foo/bar/baz');
 	t.is(normalizeUrl('sindre://www.sorhus.com'), 'sindre://sorhus.com');
@@ -69,6 +70,29 @@ test('stripProtocol option', t => {
 	t.is(normalizeUrl('sindre://www.sorhus.com', options), 'sindre://sorhus.com');
 });
 
+test('stripTextFragment option', t => {
+	t.is(normalizeUrl('http://sindresorhus.com'), 'http://sindresorhus.com');
+	t.is(normalizeUrl('http://sindresorhus.com/about#'), 'http://sindresorhus.com/about');
+	t.is(normalizeUrl('http://sindresorhus.com/about#:~:text=hello'), 'http://sindresorhus.com/about');
+	t.is(normalizeUrl('http://sindresorhus.com/about#main'), 'http://sindresorhus.com/about#main');
+	t.is(normalizeUrl('http://sindresorhus.com/about#main:~:text=hello'), 'http://sindresorhus.com/about#main');
+	t.is(normalizeUrl('http://sindresorhus.com/about#main:~:text=hello%20world'), 'http://sindresorhus.com/about#main');
+
+	const options = {stripTextFragment: false};
+	t.is(normalizeUrl('http://sindresorhus.com', options), 'http://sindresorhus.com');
+	t.is(normalizeUrl('http://sindresorhus.com/about#:~:text=hello', options), 'http://sindresorhus.com/about#:~:text=hello');
+	t.is(normalizeUrl('http://sindresorhus.com/about#main', options), 'http://sindresorhus.com/about#main');
+	t.is(normalizeUrl('http://sindresorhus.com/about#main:~:text=hello', options), 'http://sindresorhus.com/about#main:~:text=hello');
+	t.is(normalizeUrl('http://sindresorhus.com/about#main:~:text=hello%20world', options), 'http://sindresorhus.com/about#main:~:text=hello%20world');
+
+	const options2 = {stripHash: true, stripTextFragment: false};
+	t.is(normalizeUrl('http://sindresorhus.com', options2), 'http://sindresorhus.com');
+	t.is(normalizeUrl('http://sindresorhus.com/about#:~:text=hello', options2), 'http://sindresorhus.com/about');
+	t.is(normalizeUrl('http://sindresorhus.com/about#main', options2), 'http://sindresorhus.com/about');
+	t.is(normalizeUrl('http://sindresorhus.com/about#main:~:text=hello', options2), 'http://sindresorhus.com/about');
+	t.is(normalizeUrl('http://sindresorhus.com/about#main:~:text=hello%20world', options2), 'http://sindresorhus.com/about');
+});
+
 test('stripWWW option', t => {
 	const options = {stripWWW: false};
 	t.is(normalizeUrl('http://www.sindresorhus.com', options), 'http://www.sindresorhus.com');
@@ -87,7 +111,7 @@ test('stripWWW option', t => {
 test('removeQueryParameters option', t => {
 	const options = {
 		stripWWW: false,
-		removeQueryParameters: [/^utm_\w+/i, 'ref']
+		removeQueryParameters: [/^utm_\w+/i, 'ref'],
 	};
 	t.is(normalizeUrl('www.sindresorhus.com?foo=bar&utm_medium=test'), 'http://sindresorhus.com/?foo=bar');
 	t.is(normalizeUrl('http://www.sindresorhus.com', options), 'http://www.sindresorhus.com');
@@ -95,6 +119,28 @@ test('removeQueryParameters option', t => {
 	t.is(normalizeUrl('www.sindresorhus.com?foo=bar&utm_medium=test&ref=test_ref', options), 'http://www.sindresorhus.com/?foo=bar');
 });
 
+test('removeQueryParameters boolean `true` option', t => {
+	const options = {
+		stripWWW: false,
+		removeQueryParameters: true,
+	};
+
+	t.is(normalizeUrl('http://www.sindresorhus.com', options), 'http://www.sindresorhus.com');
+	t.is(normalizeUrl('www.sindresorhus.com?foo=bar', options), 'http://www.sindresorhus.com');
+	t.is(normalizeUrl('www.sindresorhus.com?foo=bar&utm_medium=test&ref=test_ref', options), 'http://www.sindresorhus.com');
+});
+
+test('removeQueryParameters boolean `false` option', t => {
+	const options = {
+		stripWWW: false,
+		removeQueryParameters: false,
+	};
+
+	t.is(normalizeUrl('http://www.sindresorhus.com', options), 'http://www.sindresorhus.com');
+	t.is(normalizeUrl('www.sindresorhus.com?foo=bar', options), 'http://www.sindresorhus.com/?foo=bar');
+	t.is(normalizeUrl('www.sindresorhus.com?foo=bar&utm_medium=test&ref=test_ref', options), 'http://www.sindresorhus.com/?foo=bar&ref=test_ref&utm_medium=test');
+});
+
 test('forceHttp option', t => {
 	const options = {forceHttp: true};
 	t.is(normalizeUrl('https://sindresorhus.com'), 'https://sindresorhus.com');
@@ -106,7 +152,9 @@ test('forceHttp option', t => {
 test('forceHttp option with forceHttps', t => {
 	t.throws(() => {
 		normalizeUrl('https://www.sindresorhus.com', {forceHttp: true, forceHttps: true});
-	}, 'The `forceHttp` and `forceHttps` options cannot be used together');
+	}, {
+		message: 'The `forceHttp` and `forceHttps` options cannot be used together',
+	});
 });
 
 test('forceHttps option', t => {
@@ -183,7 +231,7 @@ test('removeDirectoryIndex option', t => {
 test('removeTrailingSlash and removeDirectoryIndex options)', t => {
 	const options1 = {
 		removeTrailingSlash: true,
-		removeDirectoryIndex: true
+		removeDirectoryIndex: true,
 	};
 	t.is(normalizeUrl('http://sindresorhus.com/path/', options1), 'http://sindresorhus.com/path');
 	t.is(normalizeUrl('http://sindresorhus.com/path/index.html', options1), 'http://sindresorhus.com/path');
@@ -192,7 +240,7 @@ test('removeTrailingSlash and removeDirectoryIndex options)', t => {
 
 	const options2 = {
 		removeTrailingSlash: false,
-		removeDirectoryIndex: true
+		removeDirectoryIndex: true,
 	};
 	t.is(normalizeUrl('http://sindresorhus.com/path/', options2), 'http://sindresorhus.com/path/');
 	t.is(normalizeUrl('http://sindresorhus.com/path/index.html', options2), 'http://sindresorhus.com/path/');
@@ -201,7 +249,7 @@ test('removeTrailingSlash and removeDirectoryIndex options)', t => {
 
 test('sortQueryParameters option', t => {
 	const options1 = {
-		sortQueryParameters: true
+		sortQueryParameters: true,
 	};
 	t.is(normalizeUrl('http://sindresorhus.com/?a=Z&b=Y&c=X&d=W', options1), 'http://sindresorhus.com/?a=Z&b=Y&c=X&d=W');
 	t.is(normalizeUrl('http://sindresorhus.com/?b=Y&c=X&a=Z&d=W', options1), 'http://sindresorhus.com/?a=Z&b=Y&c=X&d=W');
@@ -209,7 +257,7 @@ test('sortQueryParameters option', t => {
 	t.is(normalizeUrl('http://sindresorhus.com/', options1), 'http://sindresorhus.com');
 
 	const options2 = {
-		sortQueryParameters: false
+		sortQueryParameters: false,
 	};
 	t.is(normalizeUrl('http://sindresorhus.com/?a=Z&b=Y&c=X&d=W', options2), 'http://sindresorhus.com/?a=Z&b=Y&c=X&d=W');
 	t.is(normalizeUrl('http://sindresorhus.com/?b=Y&c=X&a=Z&d=W', options2), 'http://sindresorhus.com/?b=Y&c=X&a=Z&d=W');
@@ -220,15 +268,21 @@ test('sortQueryParameters option', t => {
 test('invalid urls', t => {
 	t.throws(() => {
 		normalizeUrl('http://');
-	}, 'Invalid URL: http://');
+	}, {
+		message: /^Invalid URL/,
+	});
 
 	t.throws(() => {
 		normalizeUrl('/');
-	}, 'Invalid URL: /');
+	}, {
+		message: /^Invalid URL/,
+	});
 
 	t.throws(() => {
 		normalizeUrl('/relative/path/');
-	}, 'Invalid URL: /relative/path/');
+	}, {
+		message: /^Invalid URL/,
+	});
 });
 
 test('remove duplicate pathname slashes', t => {
@@ -255,7 +309,11 @@ test('remove duplicate pathname slashes', t => {
 
 test('data URL', t => {
 	// Invalid URL.
-	t.throws(() => normalizeUrl('data:'), 'Invalid URL: data:');
+	t.throws(() => {
+		normalizeUrl('data:');
+	}, {
+		message: 'Invalid URL: data:',
+	});
 
 	// Strip default MIME type
 	t.is(normalizeUrl('data:text/plain,foo'), 'data:,foo');
@@ -301,7 +359,7 @@ test('data URL', t => {
 		removeQueryParameters: [/^utm_\w+/i, 'ref'],
 		sortQueryParameters: true,
 		removeTrailingSlash: true,
-		removeDirectoryIndex: true
+		removeDirectoryIndex: true,
 	};
 	t.is(normalizeUrl('data:,sindresorhus.com/', options), 'data:,sindresorhus.com/');
 	t.is(normalizeUrl('data:,sindresorhus.com/index.html', options), 'data:,sindresorhus.com/index.html');
@@ -318,5 +376,21 @@ test('prevents homograph attack', t => {
 test('view-source URL', t => {
 	t.throws(() => {
 		normalizeUrl('view-source:https://www.sindresorhus.com');
-	}, '`view-source:` is not supported as it is a non-standard protocol');
+	}, {
+		message: '`view-source:` is not supported as it is a non-standard protocol',
+	});
+});
+
+test('does not have exponential performance for data URLs', t => {
+	for (let index = 0; index < 1000; index += 50) {
+		const url = 'data:' + Array.from({length: index}).fill(',#').join('') + '\ra';
+		const start = Date.now();
+
+		try {
+			normalizeUrl(url);
+		} catch {}
+
+		const difference = Date.now() - start;
+		t.true(difference < 100, `Execution time: ${difference}`);
+	}
 });
